@@ -66,6 +66,13 @@ def get_indices_tuple(labels, ref_labels, embeddings=None, ref_emb=None, miner=N
     return lmu.remove_self_comparisons(indices_tuple, curr_batch_idx, len(ref_labels))
 
 
+def gather_enqueue_mask(enqueue_mask, device):
+    if enqueue_mask is None:
+        return enqueue_mask
+    enqueue_mask = c_f.to_device(enqueue_mask, device=device)
+    return torch.cat([enqueue_mask, all_gather(enqueue_mask)], dim=0)
+
+
 def select_ref_or_regular(regular, ref):
     return regular if ref is None else ref
 
@@ -85,12 +92,18 @@ class DistributedLossWrapper(torch.nn.Module):
         self.efficient = efficient
 
     def forward(
-        self, emb, labels=None, indices_tuple=None, ref_emb=None, ref_labels=None
+        self,
+        emb,
+        labels=None,
+        indices_tuple=None,
+        ref_emb=None,
+        ref_labels=None,
+        enqueue_mask=None,
     ):
         world_size = torch.distributed.get_world_size()
         common_args = [emb, labels, indices_tuple, ref_emb, ref_labels, world_size]
         if isinstance(self.loss, CrossBatchMemory):
-            return self.forward_cross_batch(*common_args)
+            return self.forward_cross_batch(*common_args, enqueue_mask)
         return self.forward_regular_loss(*common_args)
 
     def forward_regular_loss(
@@ -118,7 +131,14 @@ class DistributedLossWrapper(torch.nn.Module):
         return loss * world_size
 
     def forward_cross_batch(
-        self, emb, labels, indices_tuple, ref_emb, ref_labels, world_size
+        self,
+        emb,
+        labels,
+        indices_tuple,
+        ref_emb,
+        ref_labels,
+        world_size,
+        enqueue_mask,
     ):
         if ref_emb is not None or ref_labels is not None:
             raise ValueError(
@@ -126,12 +146,13 @@ class DistributedLossWrapper(torch.nn.Module):
             )
 
         if world_size <= 1:
-            return self.loss(emb, labels, indices_tuple)
+            return self.loss(emb, labels, indices_tuple, enqueue_mask)
 
         all_emb, all_labels, _, _, _ = gather_emb_and_ref(
             emb, labels, ref_emb, ref_labels
         )
-        loss = self.loss(all_emb, all_labels, indices_tuple)
+        enqueue_mask = gather_enqueue_mask(enqueue_mask, emb.device)
+        loss = self.loss(all_emb, all_labels, indices_tuple, enqueue_mask)
         return loss * world_size
 
 
